summaryrefslogtreecommitdiffstats
path: root/kchart/kchartDataEditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'kchart/kchartDataEditor.h')
-rw-r--r--kchart/kchartDataEditor.h53
1 files changed, 28 insertions, 25 deletions
diff --git a/kchart/kchartDataEditor.h b/kchart/kchartDataEditor.h
index aef9a9ba..8b8d5535 100644
--- a/kchart/kchartDataEditor.h
+++ b/kchart/kchartDataEditor.h
@@ -2,16 +2,16 @@
#define KCHART_DATA_EDITOR_H
-#include <qstrlist.h>
-#include <qspinbox.h>
+#include <tqstrlist.h>
+#include <tqspinbox.h>
#include <kdialogbase.h>
#include "kchart_part.h"
-class QLabel;
-class QSpinBox;
-class QCheckBox;
+class TQLabel;
+class TQSpinBox;
+class TQCheckBox;
namespace KChart
@@ -21,7 +21,7 @@ namespace KChart
class KChartParams;
// This class inherits QSpinBox, but fixes a problem with it.
// Consider the following case:
//
// 1. The SpinBox for rows has the value 4.
@@ -38,11 +38,12 @@ class KChartParams;
//
-class kchartDataSpinBox : public QSpinBox
+class kchartDataSpinBox : public TQSpinBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- kchartDataSpinBox(QWidget *);
+ kchartDataSpinBox(TQWidget *);
~kchartDataSpinBox();
public slots:
@@ -53,7 +54,7 @@ public slots:
protected:
void interpretText(){;};
- bool eventFilter( QObject *obj, QEvent *ev );
+ bool eventFilter( TQObject *obj, TQEvent *ev );
signals:
// the value is changed (stepUp/stepDown was called or the focus is lost)
@@ -71,16 +72,17 @@ private:
// keyboard navigation in editing mode.
//
-class kchartDataTable : public QTable
+class kchartDataTable : public TQTable
{
Q_OBJECT
+ TQ_OBJECT
public:
- kchartDataTable(QWidget *);
+ kchartDataTable(TQWidget *);
~kchartDataTable();
protected:
// handles keyboard navigation
- bool eventFilter( QObject *obj, QEvent *ev );
+ bool eventFilter( TQObject *obj, TQEvent *ev );
};
@@ -90,14 +92,15 @@ protected:
class kchartDataEditor : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- kchartDataEditor(QWidget* parent = 0);
+ kchartDataEditor(TQWidget* tqparent = 0);
void setData(KChartParams *params, KDChartTableData *dat);
void getData(KChartParams *params, KDChartTableData *dat);
- void setRowLabels(const QStringList &rowLabels);
- void getRowLabels(QStringList &rowLabels);
- void setColLabels(const QStringList &colLabels);
- void getColLabels(QStringList &colLabels);
+ void setRowLabels(const TQStringList &rowLabels);
+ void getRowLabels(TQStringList &rowLabels);
+ void setColLabels(const TQStringList &colLabels);
+ void getColLabels(TQStringList &colLabels);
bool modified() const { return m_modified; }
@@ -156,17 +159,17 @@ private:
// Widgets in the editor
kchartDataTable *m_table;
- QPushButton *m_insertRowButton;
- QPushButton *m_insertColButton;
- QPushButton *m_removeRowButton;
- QPushButton *m_removeColButton;
+ TQPushButton *m_insertRowButton;
+ TQPushButton *m_insertColButton;
+ TQPushButton *m_removeRowButton;
+ TQPushButton *m_removeColButton;
- QLabel *m_rowsLA;
+ TQLabel *m_rowsLA;
kchartDataSpinBox *m_rowsSB;
- QLabel *m_colsLA;
+ TQLabel *m_colsLA;
kchartDataSpinBox *m_colsSB;
- QCheckBox *m_firstRowAsLabel;
- QCheckBox *m_firstColAsLabel;
+ TQCheckBox *m_firstRowAsLabel;
+ TQCheckBox *m_firstColAsLabel;
// This member is set to true if the user shrinks the data table,
// and confirms this by clicking OK in a warning dialog.
@@ -21,7 +21,7 @@ namespace KChart
class KChartParams;
-// This class inherits QSpinBox, but fixes a problem with it.
+// This class inherits TQSpinBox, but fixes a problem with it.
// Consider the following case:
//